<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use  App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;
use App\Model\Cms;

class CmsController extends Controller
{
    public $title = "CMS";
    public $path = "admin.cms.";
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $title = $this->title;
        $dataArr = Cms::get();
        
        return view($this->path.'index', compact('title', 'dataArr'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $title = $this->title." Create";
        $model = new Cms;
        $action = "add";
        return view($this->path.'create', compact('title', 'model', 'action'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $params = $request->all();

         $rules = [
            'contain' => "required",
        ];

        $validator = Validator::make($params, $rules, $messages = []);

        if ($validator->fails()) {
            $messages = $validator->errors();
            $errorMsg = [];
            foreach ($messages->all() as $message) {
                $errorMsg[] = $message;
            }
            return $this->errorJson([], implode('<br/>', $errorMsg));
        }


        $model = Cms::find((int)$request->get('id'));
        
        if (!$model) {
            $model = new Cms;
        }

        $model->fill($params);
        $model->save();

        return $this->successJson($model);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Model\Cms  $projectsType
     * @return \Illuminate\Http\Response
     */
    public function show(Cms $cms)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Model\ProjectsType  $projectsType
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $cms = Cms::find($id);
        $title = $cms->name;
        return view($this->path.'create', ['title' => $title, 'model' => $cms, 'action' => "edit"]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Model\ProjectsType  $cms
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Cms $cms)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Model\Cms  $cms
     * @return \Illuminate\Http\Response
     */
    public function destroy(Cms $cms)
    {
        $cms->delete();
        return $this->successJson($cms);
    }

    public function changeStatus(Request $request)
    {
        $params = $request->all();
        if (!isset($params['id'])) {
            return $this->errorJson('', 'something went wrong');
        }
        
        $status = $request->get('status', 1);
        if (Cms::where('id', $params['id'])->update(['status'=>$status])) {
            return $this->successJson('', 'success');
        } else {
            return $this->errorJson('', 'something went wrong');
        }
    }
}
