<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use  App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;
use App\Model\Faq;

class FaqController extends Controller
{
    public $title = "FAQ";
    public $path = "admin.faq.";
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $title = $this->title;
        $dataArr = Faq::get();
        
        return view($this->path.'index', compact('title', 'dataArr'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $title = $this->title." Create";
        $model = new Faq;
        $action = "add";
        return view($this->path.'create', compact('title', 'model', 'action'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $params = $request->all();

         $rules = [
            'question' => "required",
            'answer' => "required",
        ];

        $validator = Validator::make($params, $rules, $messages = []);

        if ($validator->fails()) {
            $messages = $validator->errors();
            $errorMsg = [];
            foreach ($messages->all() as $message) {
                $errorMsg[] = $message;
            }
            return $this->errorJson([], implode('<br/>', $errorMsg));
        }


        $model = Faq::find((int)$request->get('id'));
        
        if (!$model) {
            $model = new Faq;
        }

        $model->fill($params);
        $model->save();

        return $this->successJson($model);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Model\Cms  $projectsType
     * @return \Illuminate\Http\Response
     */
    public function show(Faq $faq)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Model\ProjectsType  $projectsType
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $faq = Faq::find($id);
        $title = "Edit Faq";
        return view($this->path.'create', ['title' => $title, 'model' => $faq, 'action' => "edit"]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Model\ProjectsType  $faq
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Faq $faq)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Model\Cms  $faq
     * @return \Illuminate\Http\Response
     */
    public function destroy(Faq $faq)
    {
        $faq->delete();
        return $this->successJson($faq);
    }
}
