<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Hash;
use App\Model\Pharmacist;
use App\Model\Region;
use App\Model\Skill;
use App\Model\PharmacistSkill;
use App\Model\PharmacistRegion;
use App\Model\AvailabilityOrVacancy;
use App\User;


class PharmacistController extends Controller
{
    public $title = "Pharmacist / Technician";
    public $path = "admin.pharmacist.";
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $title = $this->title;
        $dataArr = User::role('pharmacies')->get();
        
        return view($this->path.'index', compact('title', 'dataArr'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $params = $request->all();
        $id = (int)$request->get('id');

        $rules = [
            'photo' => 'max:2048|mimes:jpeg,png,jpg',
            'annual_practicing_certificate' => 'max:2048|mimes:pdf,jpeg,jpg,png,tiff',
        ];

        $validator = Validator::make($params, $rules, $messages = []);

        if ($validator->fails()) {
            $messages = $validator->errors();
            $errorMsg = [];
            foreach ($messages->all() as $message) {
                $errorMsg[] = $message;
            }
            return $this->errorJson([], implode('<br/>', $errorMsg));
        }

        $user = User::find((int)$request->get('id'));
        
        if (!$user) {
            return $this->errorJson([], "User not found please refresh page and try again");
        }

        $user->fill($params);
        $user->save();


        if($request->hasFile('photo')) {
            $file = $request->file('photo');
            $ext = $file->getClientOriginalExtension();
            $directory = '/uploads/pharmacies/photo';
            
            $name = $file->getClientOriginalName();
            $file->move(public_path().$directory, $name);

            $params['photo'] = $name;
        } else {
            unset($params['photo']);
        }

        if($request->hasFile('annual_practicing_certificate')) {
            $file = $request->file('annual_practicing_certificate');
            $ext = $file->getClientOriginalExtension();
            $directory = '/uploads/pharmacies/annual_practicing_certificate';
            
            $name = $file->getClientOriginalName();
            $file->move(public_path().$directory, $name);

            $params['annual_practicing_certificate'] = $name;
        } else {
            unset($params['annual_practicing_certificate']);
        }

        $pharmacist = $user->pharmacist;
        $pharmacist->fill($params);
        $pharmacist->save();

        PharmacistSkill::where('user_id', $user->id)->delete();
        PharmacistRegion::where('user_id', $user->id)->delete();

        if (!empty($request->get('skill_id')) && is_array($request->get('skill_id'))) {
            foreach ($request->get('skill_id') as $skill_id) {
                PharmacistSkill::create(['user_id' => $user->id, 'skill_id' => $skill_id]);
            }
        }

        if (!empty($request->get('region_id')) && is_array($request->get('region_id'))) {
            foreach ($request->get('region_id') as $region_id) {
                $pharmacist_region = $request->get('pharmacist_region');
                $pharmacist_region = $pharmacist_region[$region_id];
                $pharmacist_region['region_id'] = $region_id;
                $pharmacist_region['user_id'] = $user->id;

                PharmacistRegion::create($pharmacist_region);
            }
        }
        
        return $this->successJson($user);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Model\Skill  $projectsType
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $data = User::role('pharmacies')->find($id);
        return view($this->path.'show', compact('data'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Model\ProjectsType  $projectsType
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $user = User::role('pharmacies')->find($id);
        $skill = Skill::where('status', 1)->get();
        $region = Region::where('status', 1)->get();
        $usedRegionOnCalender = AvailabilityOrVacancy::where("user_id", $user->id)->where('region_id', '!=', '')->pluck('region_id');
        $title = $this->title;
        return view($this->path.'edit', compact('skill', 'region', 'user', 'usedRegionOnCalender', 'title'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Model\ProjectsType  $skill
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Skill $skill)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Model\Skill  $skill
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $user = User::find($id);
        $user->delete();
        return $this->successJson($user);
    }

    public function changeStatus(Request $request)
    {
        $params = $request->all();
        if (!isset($params['id'])) {
            return $this->errorJson('', 'something went wrong');
        }
        
        $status = $request->get('status', 1);
        if (User::where('id', $params['id'])->update(['status'=>$status])) {
            $user = User::find($params['id']);
            if ($user->status && !$user->is_acceptance_email_send) {
                try {
                    $user->is_acceptance_email_send = 1; 
                    $user->save();
                    
                    \Mail::send('mail.user-approval', [], function($message) use($user){
                        $message->to($user->email, $user->username);
                        $message->subject('Pharmacy Recruit Locum App');
                    });
                    
                } catch(\Exception $e) {
                    
                }
            }
            return $this->successJson('', 'success');
        } else {
            return $this->errorJson('', 'something went wrong');
        }
    }
}
