<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use  App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Hash;
use App\Model\Pharmacy;
use App\Model\Region;
use App\User;

class PharmacyController extends Controller
{
    public $title = "Pharmacy";
    public $path = "admin.pharmacy.";
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $title = $this->title;
        $dataArr = User::role('pharmacy')->get();
        
        return view($this->path.'index', compact('title', 'dataArr'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $params = $request->all();

        $id = (int)$request->get('id');

        $rules = [
            'uploads_license' => 'max:2048|mimes:pdf,jpeg,png,jpg',
            'uploads_shop_photo' => 'max:2048|mimes:jpeg,png,jpg',
        ];

        $validator = Validator::make($params, $rules, $messages = []);

        if ($validator->fails()) {
            $messages = $validator->errors();
            $errorMsg = [];
            foreach ($messages->all() as $message) {
                $errorMsg[] = $message;
            }
            return $this->errorJson([], implode('<br/>', $errorMsg));
        }

        $user = User::find((int)$request->get('id'));
        
        if (!$user) {
            return $this->errorJson([], "User not found please refresh page and try again");
        }

        $params['name'] = $params['pharmacy_name'];

        $user->fill($params);
        $user->save();

        if($request->hasFile('uploads_license')) {
            $file = $request->file('uploads_license');
            $ext = $file->getClientOriginalExtension();
            $directory = '/uploads/pharmacy/uploads_license';
            
            $name = $file->getClientOriginalName();
            $file->move(public_path().$directory, $name);

            $params['uploads_license'] = $name;
        } else {
            unset($params['uploads_license']);
        }

        if($request->hasFile('uploads_shop_photo')) {
            $file = $request->file('uploads_shop_photo');
            $ext = $file->getClientOriginalExtension();
            $directory = '/uploads/pharmacy/uploads_shop_photo';
            
            $name = $file->getClientOriginalName();
            $file->move(public_path().$directory, $name);

            $params['uploads_shop_photo'] = $name;
        } else {
            unset($params['uploads_shop_photo']);
        }


        $pharmacy = $user->pharmacy;
        $pharmacy->user_id = $user->id;
        $pharmacy->fill($params);
        $pharmacy->save();

        return $this->successJson($user);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Model\Skill  $projectsType
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $data = User::role('pharmacy')->find($id);
        return view($this->path.'show', compact('data'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Model\ProjectsType  $projectsType
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $user = User::role('pharmacy')->find($id);
        $region = Region::where('status', 1)->get();
        $title = $this->title;
        return view($this->path.'edit', compact('user', 'region', 'title'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Model\ProjectsType  $skill
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Skill $skill)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Model\Skill  $skill
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $user = User::find($id);
        $user->delete();
        return $this->successJson($user);
    }

    public function changeStatus(Request $request)
    {
        $params = $request->all();
        if (!isset($params['id'])) {
            return $this->errorJson('', 'something went wrong');
        }
        
        $status = $request->get('status', 1);
        if (User::where('id', $params['id'])->update(['status'=>$status])) {
            $user = User::find($params['id']);
            if ($user->status && !$user->is_acceptance_email_send) {
                try {
                    $user->is_acceptance_email_send = 1; 
                    $user->save();
                    
                    \Mail::send('mail.user-approval', [], function($message) use($user){
                        $message->to($user->email, $user->username);
                        $message->subject('Pharmacy Recruit Locum App');
                    });
                    
                } catch(\Exception $e) {
                    
                }
            }
            return $this->successJson('', 'success');
        } else {
            return $this->errorJson('', 'something went wrong');
        }
    }
}
