<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use  App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;
use App\Model\Skill;

class SkillController extends Controller
{
    public $title = "Skill";
    public $path = "admin.skill.";
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $title = $this->title;
        $dataArr = Skill::get();
        
        return view($this->path.'index', compact('title', 'dataArr'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $title = $this->title." Create";
        $model = new Skill;
        $action = "add";
        return view($this->path.'create', compact('title', 'model', 'action'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $params = $request->all();

         $rules = [
            'name' => "required",
        ];

        $validator = Validator::make($params, $rules, $messages = []);

        if ($validator->fails()) {
            $messages = $validator->errors();
            $errorMsg = [];
            foreach ($messages->all() as $message) {
                $errorMsg[] = $message;
            }
            return $this->errorJson([], implode('<br/>', $errorMsg));
        }


        $model = Skill::find((int)$request->get('id'));
        
        if (!$model) {
            $model = new Skill;
        }

        $model->fill($params);
        $model->save();

        return $this->successJson($model);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Model\Skill  $projectsType
     * @return \Illuminate\Http\Response
     */
    public function show(Skill $skill)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Model\ProjectsType  $projectsType
     * @return \Illuminate\Http\Response
     */
    public function edit(Skill $skill)
    {
        $title = $this->title." Update";
        return view($this->path.'create', ['title' => $title, 'model' => $skill, 'action' => "edit"]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Model\ProjectsType  $skill
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Skill $skill)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Model\Skill  $skill
     * @return \Illuminate\Http\Response
     */
    public function destroy(Skill $skill)
    {
        $skill->delete();
        return $this->successJson($skill);
    }

    public function changeStatus(Request $request)
    {
        $params = $request->all();
        if (!isset($params['id'])) {
            return $this->errorJson('', 'something went wrong');
        }
        
        $status = $request->get('status', 1);
        if (Skill::where('id', $params['id'])->update(['status'=>$status])) {
            return $this->successJson('', 'success');
        } else {
            return $this->errorJson('', 'something went wrong');
        }
    }
}
