<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use Illuminate\Foundation\Auth\SendsPasswordResetEmails;
use Illuminate\Http\Request; 
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Str;
use Carbon\Carbon; 

class ForgotPasswordController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Password Reset Controller
    |--------------------------------------------------------------------------
    |
    | This controller is responsible for handling password reset emails and
    | includes a trait which assists in sending these notifications from
    | your application to your users. Feel free to explore this trait.
    |
    */

    use SendsPasswordResetEmails;
    
    public function sendResetLinkEmail(Request $request)
    {
        
        $request->validate([
            'username' => 'required',
        ]);
        
        $user = \App\User::where('username', $request->username)->first();
        
        if (!$user) {
            return back()
                ->withInput($request->only('username'))
                ->withErrors(['username' => "Username does not exist"]);
        }
        
        $request->request->add(['email' => $user->email]);
        
        $token = Str::random(64);
        
        DB::table('password_resets')->insert(
            ['username' => $request->username, 'token' => $token, 'created_at' => Carbon::now()]
        );
    
        $user->sendPasswordResetNotification($token);
        
        return back()->with('status', 'We have e-mailed your password reset link!');
    }
}
