<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;
use App\User;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = "/";

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'username' => ['required', 'string', 'max:255', 'unique:users,username'],
            'email' => ['required', 'string', 'email', 'max:255', \Illuminate\Validation\Rule::unique('users')->where(function ($query) {
                return $query->whereRaw(" exists (select * from `roles` inner join `model_has_roles` on `roles`.`id` = `model_has_roles`.`role_id` where `users`.`id` = `model_has_roles`.`model_id`  and `name` = '".request()->role_name."') ");
            })],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
            'role_name' => ['required'],
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\User
     */
    protected function create(array $data)
    {
        $user = User::create([
            'username' => $data['username'],
            'email' => $data['email'],
            'password' => Hash::make($data['password']),
            'status' => 0,
            'show_registration' => 1,
        ]);

        $user->assignRole($data['role_name']);
        
        try {
            \Mail::send('mail.user-ragister', ['name' => $user->username], function($message) use($user){
                $message->to($user->email, $user->username);
                $message->subject('Thank you for registering on Pharmacy Recruit');
            });
            
            $adminEmail = \App\Model\Setting::where('key', 'ADMIN_EMAIL')->value('value');
            if ($adminEmail)
            \Mail::send('mail.admin-ragister', ['role_name' => $data['role_name']], function($message) use($data){
                $message->to($adminEmail, 'Admin');
                $message->subject('New '.$data['role_name'].' new sign up');
            });
            
        } catch(\Exception $e) {
            
        }

        return $user;
    }
}
