<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;
use Illuminate\Foundation\Auth\ResetsPasswords;
use Illuminate\Http\Request; 
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use App\User; 

class ResetPasswordController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Password Reset Controller
    |--------------------------------------------------------------------------
    |
    | This controller is responsible for handling password reset requests
    | and uses a simple trait to include this behavior. You're free to
    | explore this trait and override any methods you wish to tweak.
    |
    */

    use ResetsPasswords;

    /**
     * Where to redirect users after resetting their password.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    protected function rules()
    {
        return [
            'token' => 'required',
            'email' => 'required|email',
            'password' => 'required|min:8',
        ];
    }
    
    public function reset(Request $request)
    {
        $request->validate($this->rules(), $this->validationErrorMessages());

       $updatePassword = DB::table('password_resets')
                      ->where(['token' => $request->token])
                      ->first();

      if(!$updatePassword)
          return back()->withInput($request->only('email'))->with('error', 'Invalid token!');
    
        $user = User::where('username', $updatePassword->username)
                    ->update(['password' => Hash::make($request->password)]);
    
        DB::table('password_resets')->where(['username'=> $request->username])->delete();
    
        return redirect($this->redirectPath())->with('status', 'Your password has been changed!');
    }
}
