<?php

namespace App\Http\Controllers\Front;

use Illuminate\Http\Request;
use  App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Hash;
use App\Model\Booking;
use App\Model\Setting;
use App\Model\Notification;
use App\Model\Invoice;
use App\Model\InvoiceExtra;
use App\Model\PharmacistRegion;
use App\User;
use PDF;

class BookingsController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        //$this->middleware('auth');
    }

    public function index()
    {
        $roleId = auth()->user()->roles->first()->id;
        if ($roleId == '2') {
            $bookings = Booking::where(function($query) {
                $query->where("created_by", auth()->user()->id);
                $query->orWhere("user_id", auth()->user()->id);
            })->paginate(10);
            return view('front.booking.pharmacist-booking', compact('bookings'));
        } elseif ($roleId == '3') {
            $bookings = Booking::where(function($query) {
                $query->where("created_by", auth()->user()->id);
                $query->orWhere("pharmacy_id", auth()->user()->pharmacy_id);
            })->paginate(10);
            
            $pharmacyLocation = auth()->user()->pharmacyByUserId;
            return view('front.booking.pharmacy-booking', compact('bookings', 'pharmacyLocation'));
        }
    }

    public function store(Request $request)
    {
        $params = $request->all();
                
        $booking = new Booking;
        if (!empty($params['date'])) {
            foreach ($params['date'] as $k => $v) {
                $params['date'][$k] = date('Y-m-d', strtotime($v));
            }
        }
        $booking->fill($params);
        $booking->save();
        
        try {
            \Mail::send('mail.booking', ['booking'=> $booking], function($message) use($booking){
                $message->to($booking->user->email, $booking->user->username);
                if ($booking->is_invite) {
                    $message->subject("New invitation by ".(auth()->user()->name ?? (auth()->user()->firstname.' '.auth()->user()->lastname)));
                } else {
                    $message->subject("Add New booking by ".(auth()->user()->name ?? (auth()->user()->firstname.' '.auth()->user()->lastname)));
                }
                
            });
            
        } catch(\Exception $e) {
            
        }
        $notification = new Notification;
        $params['booking_id'] = $booking->id;
        if ($request->get('is_invite')) {
            $params['notes'] = "New invitation by ".(auth()->user()->name ?? (auth()->user()->firstname.' '.auth()->user()->lastname));
        } else {
            $params['notes'] = "Add New booking by ".(auth()->user()->name ?? (auth()->user()->firstname.' '.auth()->user()->lastname));
        }
        $notification->fill($params);
        $notification->save();

        

        return $this->successJson($booking);
    }

    public function show($id)
    {
        $booking = Booking::findOrFail($id);

        if ($booking->status == 0 && $booking->created_by != auth()->user()->id) {
            if (auth()->user()->roles->first()->id == '2') {
                return redirect()->route('request-from-pharmacy', $id);
            } else {
                return redirect()->route('request-from-pharmacist', $id);
            }
        }

        $roleId = auth()->user()->roles->first()->id;
        if ($roleId == '2') {
            return view('front.booking.pharmacist-booking-show', compact('booking'));
        } elseif ($roleId == '3') {
            return view('front.booking.pharmacy-booking-show', compact('booking'));
        }
    }

    public function requestFromPharmacy($id) {
        $booking = Booking::findOrFail($id);
        return view('front.booking.request-from-pharmacy', compact('booking'));
    }

    public function requestFromPharmacist($id) {
        $booking = Booking::findOrFail($id);
        return view('front.booking.request-from-pharmacist', compact('booking'));
    }

    public function changeStatus($id, $status) {
        $booking = Booking::findOrFail($id);

        if ($status == 2) {
            $booking->status = 2;
            $booking->save();

            Notification::create([
                'booking_id'    => $booking->id,
                'user_id'       => $booking->created_by,
                'created_by'    => $booking->user_id,
                'pharmacy_id'   => $booking->pharmacy_id,
                'notes'         => "Your booking decline by ".(auth()->user()->name ?? (auth()->user()->firstname.' '.auth()->user()->lastname)),
            ]);

            try {
                \Mail::raw('Hello,
    
Your booking decline by '.(auth()->user()->name ?? (auth()->user()->firstname.' '.auth()->user()->lastname)).'.

Pharmacy Recruit Team
                
                ', function ($message) use($booking) {
                    if ($booking->createdBy->roles->first()->id == '2') {
                        $message->to($booking->user->email , $booking->user->username);
                    } else {
                        $message->to($booking->createdBy->email , $booking->createdBy->username);
                    }
                    $message->subject("Your booking decline by ".(auth()->user()->name ?? (auth()->user()->firstname.' '.auth()->user()->lastname)).' | Pharmacy Recruit');
                });
            } catch(\Exception $e) {
                
            }
        } else {
            if (auth()->user()->roles->first()->id == '3') {
                return redirect()->route('booking.pay', $id);
            } else {
                $booking->status = 1;
                $booking->save();

                Notification::create([
                    'booking_id'    => $booking->id,
                    'user_id'       => $booking->created_by,
                    'created_by'    => $booking->user_id,
                    'pharmacy_id'   => $booking->pharmacy_id,
                    'notes'         => "Your booking accept by ".(auth()->user()->name ?? (auth()->user()->firstname.' '.auth()->user()->lastname)),
                ]);
                
                $day = count($booking->date);
                $per_day_price = Setting::where('key', 'PER_DAY_PRICE')->value('value');
                $price = $day * $per_day_price;
                $gst_percentage = Setting::where('key', 'GST')->value('value');
                
                
                $invoice = Invoice::create([
                    'booking_id'    => $booking->id,
                    'user_id'       => auth()->user()->id,
                    'description'   => $booking->pharmacy->pharmacy_name,
                    'day'           => $day,
                    'per_day_price' => $per_day_price,
                    'price'         => $price,
                    'gst_percentage'=> $gst_percentage,
                ]);
                
                $pharmacistRegion = PharmacistRegion::where(['user_id' => auth()->user()->id, 'region_id' => $booking->pharmacy->region_id])->first();
                
                if ($pharmacistRegion) {
                    if (!empty($pharmacistRegion->accommodation_id) && !in_array(1, $pharmacistRegion->accommodation_id)) {
                        $price = Setting::where('key', 'ACCOMODATION_PRICE')->value('value');
                        InvoiceExtra::create([
                            'invoice_id'    => $invoice->id,
                            'description'   => $pharmacistRegion->getAccommodation(),
                            'price'         => $price,
                        ]);
                    }
                    
                    if (!empty($pharmacistRegion->travel_costs_id) && !in_array(1, $pharmacistRegion->travel_costs_id)) {
                        $price = Setting::where('key', 'FLIGHTS_PRICE')->value('value');
                        InvoiceExtra::create([
                            'invoice_id'    => $invoice->id,
                            'description'   => $pharmacistRegion->getTravelCosts(),
                            'price'         => $price,
                        ]);
                    }
                }
                
                $sub_total = $invoice->price;
                
                foreach($invoice->invoiceExtra as $invoiceExtra) {
                    $sub_total += $invoiceExtra->price;
                }
                
                $gst = ($sub_total * $invoice->gst_percentage) / 100;
                $total =  $sub_total + $gst;
                
                $invoice->gst = $gst;
                $invoice->sub_total = $sub_total;
                $invoice->total = $total;
                $invoice->save();
                
                $filename = time().'.pdf';
                if (!is_dir(public_path('invoice'))) {
                    mkdir(public_path('invoice'));
                }
                
                $path = public_path('invoice');
                
                $pdf = PDF::loadView('invoice-pdf', compact('booking', 'invoice'));
                $pdf->save($path . '/' . $filename);
                $invoice->pdf_path = $filename;
                $invoice->save();
                
                try {
                    \Mail::raw('Hello,
        
Please find attached Pharmacy Recruit Invoice.

Pharmacy Recruit Team
                    
                    ', function ($message) use($path, $filename, $booking) {
                        if ($booking->createdBy->roles->first()->id == '2') {
                            $message->to($booking->user->email , $booking->user->username);
                        } else {
                            $message->to($booking->createdBy->email , $booking->createdBy->username);
                        }
                        $message->subject('Pharmacy Recruit Invoice');
                        $message->attach($path . '/' . $filename);
                    });
                } catch(\Exception $e) {
                    
                }
            }
        }
        return redirect()->route('booking.show', $id);
    }

    public function invoice($id) {
        
        $booking = Booking::findOrFail($id);
        $invoice = Invoice::where(['booking_id' => $booking->id])->first();
        if (!$invoice) {
            abort(404);
        } 
        return view('front.booking.invoice', compact('booking', 'invoice'));
    }
    
    public function payment($id) {
        $booking = Booking::findOrFail($id);
        $amount = 5;
        $stripe = new \Stripe\StripeClient('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');
        $intent = $stripe->paymentIntents->create([
                  'amount' => $amount * 100,
                  'currency' => 'NZD',
                  // Verify your integration in this guide by including this parameter
                  'metadata' => ['integration_check' => 'accept_a_payment'],
                ]);
        return view('front.booking.payment', compact('booking', 'intent', 'amount'));
    }

    public function paymentSucceeded(Request $request) {
        $params = $request->all();

        if ( $params['booking_id'] > 0) {
            $id = $params['booking_id'];
            $booking = Booking::findOrFail($id);
            
            $amount = ($params['amount'] / 100);
            
            \DB::table('transaction')->insert([
                'booking_id' => $id,
                'amount' => $amount,
                'transaction_ref' => $params['id'],
            ]);

            $booking->status = 1;
            $booking->save();

            Notification::create([
                'booking_id'    => $booking->id,
                'user_id'       => $booking->created_by,
                'created_by'    => $booking->user_id,
                'pharmacy_id'   => $booking->pharmacy_id,
                'notes'         => "Your booking accept by ".(auth()->user()->name ?? (auth()->user()->firstname.' '.auth()->user()->lastname)),
            ]);

            try {
                \Mail::raw('Hello,
    
Your booking accept by '.(auth()->user()->name ?? (auth()->user()->firstname.' '.auth()->user()->lastname)).'.

Pharmacy Recruit Team
                
                ', function ($message) use($booking) {
                    if ($booking->createdBy->roles->first()->id == '2') {
                        $message->to($booking->user->email , $booking->user->username);
                    } else {
                        $message->to($booking->createdBy->email , $booking->createdBy->username);
                    }
                    $message->subject("Your booking accept by ".(auth()->user()->name ?? (auth()->user()->firstname.' '.auth()->user()->lastname)).' | Pharmacy Recruit');
                });
            } catch(\Exception $e) {
                
            }
            return $this->successJson(route('booking.show', $id), "Added wallet payment successfully");
        } else {
            return $this->errorJson('', 'something went wrong');
        }
    }
}
