<?php

namespace App\Http\Controllers\Front;

use Illuminate\Http\Request;
use  App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Hash;
use App\Model\Pharmacist;
use App\Model\Pharmacy;
use App\Model\Region;
use App\Model\Skill;
use App\Model\PharmacistSkill;
use App\Model\PharmacistRegion;
use App\Model\AvailabilityOrVacancy;
use App\User;

use Illuminate\Pagination\Paginator;
use Illuminate\Support\Collection;
use Illuminate\Pagination\LengthAwarePaginator;

class PharmacistController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        //$this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function registration()
    {
        $skill = Skill::where('status', 1)->get();
        $region = Region::where('status', 1)->get();
        $user = auth()->user();
        return view('front.pharmacist.registration', compact('skill', 'region', 'user'));
    }

    public function dashboard()
    {
        $user = auth()->user();

        $availabilityOrVacancy = AvailabilityOrVacancy::getAllDate();
        $pharmacistRegion = auth()->user()->pharmacistRegion;
        $regionIdArr = [0];
        foreach ($pharmacistRegion as $value) {
            $regionIdArr[] = $value->region_id;
        }

        $vacancies = User::select("pharmacy.*")->join("pharmacy", "users.id", "=", "pharmacy.user_id")
                                ->whereIn("pharmacy.region_id", $regionIdArr)
                                ->where("pharmacy.region_id", "!=", "0")
                                ->where("users.status", 1)
                                ->orderBy("users.id", "desc")
                                ->get();
        $vacancyArr = [];
        foreach ($vacancies as $vacancy) {
            if (count($vacancyArr) < 3) {
                $vacancydate = AvailabilityOrVacancy::where("pharmacy_id", $vacancy->id)->get();
                $date = AvailabilityOrVacancy::getUserDate($vacancydate);

                if (!empty($date)) {
                    $startDate = reset($date);
                    $endDate = end($date);

                    if (time() <= strtotime($endDate) ) {
                        if ($startDate == $endDate) {
                            $vacancyArr[] = [
                                'name' => $vacancy->pharmacy_name,
                                'location' => $vacancy->address,
                                'date' => $startDate
                            ];
                        } else {
                            $vacancyArr[] = [
                                'name' => $vacancy->pharmacy_name,
                                'location' => $vacancy->address,
                                'date' => $startDate . " to ". $endDate
                            ];
                        }
                    }
                }
            }
        }

        return view('front.pharmacist.dashboard', compact('user', 'availabilityOrVacancy', 'vacancyArr'));
    }

    public function edit()
    {
        $skill = Skill::where('status', 1)->get();
        $region = Region::where('status', 1)->get();
        $user = auth()->user();
        $usedRegionOnCalender = AvailabilityOrVacancy::where("user_id", auth()->user()->id)->where('region_id', '!=', '')->pluck('region_id');
        return view('front.pharmacist.edit', compact('skill', 'region', 'user', 'usedRegionOnCalender'));
    }

    public function store(Request $request)
    {
        $params = $request->all();
        $id = (int)$request->get('id');

        $rules = [
            'photo' => 'max:2048|mimes:jpeg,png,jpg',
            'annual_practicing_certificate' => 'max:2048|mimes:pdf,jpeg,jpg,png,tiff',
        ];

        $validator = Validator::make($params, $rules, $messages = []);

        if ($validator->fails()) {
            $messages = $validator->errors();
            $errorMsg = [];
            foreach ($messages->all() as $message) {
                $errorMsg[] = $message;
            }
            return $this->errorJson([], implode('<br/>', $errorMsg));
        }

        $user = User::find((int)$request->get('id'));
        
        if (!$user) {
            return $this->errorJson([], "User not found please refresh page and try again");
        }

        if (isset($params['submit']) && $params['submit'] == "Submit") {
            $params['show_registration'] = 0;
        }

        $user->fill($params);
        $user->save();


        if($request->hasFile('photo')) {
            $file = $request->file('photo');
            $ext = $file->getClientOriginalExtension();
            $directory = '/uploads/pharmacies/photo';
            
            $name = $file->getClientOriginalName();
            $file->move(public_path().$directory, $name);

            $params['photo'] = $name;
        } else {
            unset($params['photo']);
        }

        if($request->hasFile('annual_practicing_certificate')) {
            $file = $request->file('annual_practicing_certificate');
            $ext = $file->getClientOriginalExtension();
            $directory = '/uploads/pharmacies/annual_practicing_certificate';
            
            $name = $file->getClientOriginalName();
            $file->move(public_path().$directory, $name);

            $params['annual_practicing_certificate'] = $name;
        } else {
            unset($params['annual_practicing_certificate']);
        }

        $pharmacist = $user->pharmacist;
        $pharmacist->fill($params);
        $pharmacist->save();

        PharmacistSkill::where('user_id', $user->id)->delete();
        PharmacistRegion::where('user_id', $user->id)->delete();

        if (!empty($request->get('skill_id')) && is_array($request->get('skill_id'))) {
            foreach ($request->get('skill_id') as $skill_id) {
                PharmacistSkill::create(['user_id' => $user->id, 'skill_id' => $skill_id]);
            }
        }

        if (!empty($request->get('region_id')) && is_array($request->get('region_id'))) {
            foreach ($request->get('region_id') as $region_id) {
                $pharmacist_region = $request->get('pharmacist_region');
                $pharmacist_region = $pharmacist_region[$region_id];
                $pharmacist_region['region_id'] = $region_id;
                $pharmacist_region['user_id'] = $user->id;

                PharmacistRegion::create($pharmacist_region);
            }
        }
        
        auth()->setUser($user);

        return $this->successJson($user);
    }

    public function job($sorted = null) {
        

        $pharmacistRegion = auth()->user()->pharmacistRegion;
        $regionIdArr = [0];
        foreach ($pharmacistRegion as $value) {
            $regionIdArr[] = $value->region_id;
        }

        $pharmacy = User::select("pharmacy.*")->join("pharmacy", "users.id", "=", "pharmacy.user_id")
                                ->whereIn("pharmacy.region_id", $regionIdArr)
                                ->where("pharmacy.region_id", "!=", "0")
                                ->where("users.status",  "=", "1")
                                ->where("users.show_registration",  "=", "0");

        if ($sorted == "old") {
            $pharmacy = $pharmacy->orderBy("users.id", "DESC");
        } else {
            $pharmacy = $pharmacy->orderBy("users.id", "ASC");
        }

        $pharmacyArr = $pharmacy->get();

        $pharmacy = [];
        foreach ($pharmacyArr as $pharm) {
            $vacancydate = AvailabilityOrVacancy::where("pharmacy_id", $pharm->id)->get();
            $date = AvailabilityOrVacancy::getUserDate($vacancydate);
           
            if (!empty($date)) {
                $startDate = reset($date);
                $endDate = end($date);
                 
                if ($startDate == $endDate) {
                    $pharm->start_end_date = $startDate;
                } else {
                    $pharm->start_end_date = $startDate . " to ". $endDate;
                }
                
                //echo '<pre>'; print_r([date("Y-m-d"), date("Y-m-d",strtotime($endDate.' -2 days'))]);die;
                if (time() <= strtotime($endDate.' -2 days')) {
                    $pharmacy[] = $pharm;
                }
            }
        }
        
        $pharmacy = $this->paginate($pharmacy);
        
        unset($pharm);
        return view('front.pharmacist.job',  compact('pharmacy', 'sorted'));
    }
    
    public function paginate($items, $perPage = 5, $page = null, $options = [])
    {
        $page = $page ?: (Paginator::resolveCurrentPage() ?: 1);
        $items = $items instanceof Collection ? $items : Collection::make($items);
        return new LengthAwarePaginator($items->forPage($page, $perPage), $items->count(), $perPage, $page, $options);
    }
    
    public function pharmacy($id) {
        $pharmacy = Pharmacy::findOrfail($id);
        $availabilityOrVacancy = AvailabilityOrVacancy::where("pharmacy_id", $pharmacy->id)->get();
        $availabilityOrVacancy = AvailabilityOrVacancy::getUserDate($availabilityOrVacancy, true);
        return view('front.pharmacist.pharmacy',  compact('pharmacy','availabilityOrVacancy'));
    }
}
