<?php

namespace App\Http\Controllers\Front;

use Illuminate\Http\Request;
use  App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Hash;
use App\Model\Pharmacy;
use App\Model\Region;
use App\Model\AvailabilityOrVacancy;
use App\User;

class PharmacyController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        //$this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function registration()
    {
        $region = Region::where('status', 1)->get();
        $user = auth()->user();
        return view('front.pharmacy.registration',  compact('region', 'user'));
    }

    public function dashboard()
    {
        $pharmacyLocation = auth()->user()->pharmacyByUserId;
        $availabilityOrVacancy = AvailabilityOrVacancy::getAllDate();

        $suggestedPerson = User::select("users.*")->join("pharmacist_region", "users.id", "=", "pharmacist_region.user_id")
                                ->where("pharmacist_region.region_id", auth()->user()->pharmacy->region_id)
                                ->where("users.status", 1)
                                ->groupBy("users.id")
                                ->orderBy("users.id", "desc")
                                ->get();
        $suggestedPersonArr = [];
        foreach ($suggestedPerson as $sp) {
            if (count($suggestedPersonArr) < 3) {
                $dateList = AvailabilityOrVacancy::where("user_id", $sp->id)->get();
                $date = AvailabilityOrVacancy::getUserDate($dateList);

                if (!empty($date)) {
                    $startDate = reset($date);
                    $endDate = end($date);

                    if (time() <= strtotime($endDate) ) {
                        if ($startDate == $endDate) {
                            $suggestedPersonArr[] = [
                                'id' => $sp->id,
                                'name' => $sp->firstname.' '.$sp->lastname,
                                'location' => $sp->pharmacist->location,
                                'date' => $startDate
                            ];
                        } else {
                            $suggestedPersonArr[] = [
                                'id' => $sp->id,
                                'name' => $sp->firstname.' '.$sp->lastname,
                                'location' => $sp->pharmacist->location,
                                'date' => $startDate . " to ". $endDate
                            ];
                        }
                    }
                }
            }
        }
        
        return view('front.pharmacy.dashboard', compact('pharmacyLocation', 'availabilityOrVacancy', 'suggestedPersonArr'));
    }

    public function edit()
    {
       $user = auth()->user();
        $region = Region::where('status', 1)->get();
        return view('front.pharmacy.edit', compact('user', 'region'));
    }

    public function store(Request $request)
    {
        $params = $request->all();

        $id = (int)$request->get('id');

        if ($request->get('action') == "add") {
            $rules = [
                'uploads_license' => 'max:2048|mimes:pdf,jpeg,png,jpg',
                'uploads_shop_photo' => 'max:2048|mimes:jpeg,png,jpg',
            ];

            $validator = Validator::make($params, $rules, $messages = []);

            if ($validator->fails()) {
                $messages = $validator->errors();
                $errorMsg = [];
                foreach ($messages->all() as $message) {
                    $errorMsg[] = $message;
                }
                return $this->errorJson([], implode('<br/>', $errorMsg));
            }
        }

        $user = User::find((int)$request->get('id'));
        
        if (!$user) {
            return $this->errorJson([], "User not found please refresh page and try again");
        }

        $params['name'] = $params['pharmacy_name'];

        if (isset($params['submit']) && $params['submit'] == "Submit") {
            $params['show_registration'] = 0;
        }

        $user->fill($params);
        $user->save();

        if($request->hasFile('uploads_license')) {
            $file = $request->file('uploads_license');
            $ext = $file->getClientOriginalExtension();
            $directory = '/uploads/pharmacy/uploads_license';
            
            $name = $file->getClientOriginalName();
            $file->move(public_path().$directory, $name);

            $params['uploads_license'] = $name;
        } else {
            unset($params['uploads_license']);
        }

        if($request->hasFile('uploads_shop_photo')) {
            $file = $request->file('uploads_shop_photo');
            $ext = $file->getClientOriginalExtension();
            $directory = '/uploads/pharmacy/uploads_shop_photo';
            
            $name = $file->getClientOriginalName();
            $file->move(public_path().$directory, $name);

            $params['uploads_shop_photo'] = $name;
        } else {
            unset($params['uploads_shop_photo']);
        }


        $pharmacy = $user->pharmacy;
        $pharmacy->user_id = $user->id;
        $pharmacy->fill($params);
        $pharmacy->save();

        if ($request->get('action') == "add") {
            $user->pharmacy_id = $pharmacy->id;
            $user->save();
        }

        if ($request->get('action') == "update") {
            auth()->setUser($user);
        }
        
        return $this->successJson($user);
    }

    public function search($sorted = null) {
        
        $pharmacist = User::select("users.*")->join("pharmacist_region", "users.id", "=", "pharmacist_region.user_id")
                                ->where("pharmacist_region.region_id", auth()->user()->pharmacy->region_id)
                                ->where("users.status", 1)
                                ->groupBy("users.id");

        if ($sorted == "old") {
            $pharmacist = $pharmacist->orderBy("users.id", "ASC");
        } else {
            $pharmacist = $pharmacist->orderBy("users.id", "DESC");
        }

        $pharmacist = $pharmacist->paginate(10);

        return view('front.pharmacy.search',  compact('pharmacist', 'sorted'));
    }

    public function pharmacist($id) {
        $user = User::findOrfail($id);
        $availabilityOrVacancy = AvailabilityOrVacancy::where("user_id", $user->id)->get();
        $availabilityOrVacancy = AvailabilityOrVacancy::getUserDate($availabilityOrVacancy, true);
        return view('front.pharmacy.pharmacist',  compact('user','availabilityOrVacancy'));
    }
    
    public function destroy()
    {

        $pharmacy = auth()->user()->pharmacy;
        $pharmacy->delete();
        
        $user = auth()->user();
        $user->pharmacy_id = $user->pharmacyLocation()->first()->id;
        $user->save();
        
        return $this->successJson($pharmacy);
    }
}
