<?php

namespace App\Model;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class AvailabilityOrVacancy extends Model
{
	use SoftDeletes;

    public $table = "availability_or_vacancy";

    protected $fillable = [
        'user_id',
        'region_id',
        'pharmacy_id',
        'recurring',
        'recurring_day_of_week',
        'recurring_from',
        'recurring_until',
        'date',
        'vacancy_for',
        'notes',
    ];

    public static function getAllDate() {
        $availabilityOrVacancy = self::where("user_id", auth()->user()->id);
        if (auth()->user()->roles->first()->id == '3') {
            $availabilityOrVacancy = $availabilityOrVacancy->where("pharmacy_id", auth()->user()->pharmacy_id);
        }

        $availabilityOrVacancy = $availabilityOrVacancy->get();
        return self::getUserDate($availabilityOrVacancy, true);

    }

    public static function getUserDate($availabilityOrVacancy, $isCheckDateStatusClass = false) {
        $date = [];
        foreach ($availabilityOrVacancy as $aov) {
            if ($aov->recurring) {
                if (!empty(strtotime($aov->recurring_from)) && !empty(strtotime($aov->recurring_until))) {
                    $recurring_from = strtotime($aov->recurring_from);
                    $recurring_until = strtotime($aov->recurring_until);
                    while ($recurring_from <= $recurring_until) {
                        if ($aov->recurring == 2 || date('l', $recurring_from) == $aov->recurring_day_of_week) {
                            if ($isCheckDateStatusClass) {
                                $date[] = [
                                    'id'  => $aov->id,
                                    'date'  => date('Y-m-d', $recurring_from),
                                    'class' => self::checkDateStatusClass(date('Y-m-d', $recurring_from)),
                                    'title' =>( $aov->vacancy_for == '2' ? 'Technician' : 'Pharmacist')
                                ];
                            } else {
                                $date[] = date('Y-m-d', $recurring_from);
                            }
                        }
                        $recurring_from = strtotime("+1 day", $recurring_from);
                    }
                }
            } else if(!empty($aov->date))  {
                if ($isCheckDateStatusClass) {
                    $date[] = [
                        'id'  => $aov->id,
                        'date'  => $aov->date,
                        'class' => self::checkDateStatusClass($aov->date),
                        'title' =>( $aov->vacancy_for == '2' ? 'Technician' : 'Pharmacist')
                    ];
                } else {
                    $date[] = $aov->date;
                }
            }
        }

        return $date;
    }

    /*
        Red :Not available (default)
        Green: Available
        BLUE: Booked
        Orange: Offered
    */
    public static function checkDateStatusClass($date) {
        $status = "date-green";
        if ($date) {
            if (Booking::where('date', 'like', '%'.$date.'%')->where(function($query) {
                $query->where("created_by", auth()->user()->id);
                $query->orWhere("user_id", auth()->user()->id);
            })->where('status', '=', '1')->count()) {
                $status = "date-blue";
            } else if ( Booking::where('date', 'like', '%'.$date.'%')->where(function($query) {
                $query->where("created_by", auth()->user()->id);
                $query->orWhere("user_id", auth()->user()->id);
            })->where('status', '=', '2')->count() ){
                $status = "date-orange";
            }
        }

        return $status;
    }
}
