<?php

namespace App\Model;

use Illuminate\Database\Eloquent\Model;

class PharmacistRegion extends Model
{
	public $table = "pharmacist_region";

    protected $fillable = [
        'user_id',
        'region_id',
        'accommodation_id',
        'travel_costs_id',
        'rate_expectation',
    ];
    
    protected $casts = [
        'accommodation_id' => 'array',
        'travel_costs_id' => 'array',
    ];
    
    public static $accommodation = [
        '1' => 'Accommodation not required',
        '2' => 'Motel',
        '3' => 'Hotel',
        '4' => 'Airbnb or Bookabach',
        '5' => 'With owner or staff',
    ];

    public static $travel_costs = [
        '1' => 'Travel costs not required',
        '2' => 'Road Travel at 70% of current IRD rates per kilometer',
        '3' => 'Road Travel at 100% of current IRD rates per kilometer',
        '4' => 'Taxi fares',
        '5' => 'Flight costs'
    ];

    public function region() {
        return $this->hasOne('App\Model\Region', 'id', 'region_id')->withDefault();
    }

    public function user() {
        return $this->hasOne('App\User', 'id', 'user_id')->withDefault();
    }

    public function getAccommodation() {
        $accommodation = [];
        foreach ((array)$this->accommodation_id as $accommodation_id) {
            if (isset(self::$accommodation[$accommodation_id])) {
                $accommodation[] = self::$accommodation[$accommodation_id];
            }
        }
        return implode(', ', $accommodation); 
    }

    public function getTravelCosts() {
        $travel_costs = [];
        foreach ((array)$this->travel_costs_id as $travel_costs_id) {
            if (isset(self::$travel_costs[$travel_costs_id])) {
                $travel_costs[] = self::$travel_costs[$travel_costs_id];
            }
        }
        return implode(', ', $travel_costs);
    }
}
