<?php

namespace App;

use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Illuminate\Database\Eloquent\SoftDeletes;
use Spatie\Permission\Traits\HasRoles;
use Spatie\Permission\Models\Role;


class User extends Authenticatable
{
    use Notifiable, SoftDeletes, HasRoles;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name', 'firstname', 'lastname', 'username', 'email', 'password', 'status', 'pharmacy_id', 'show_registration', 'is_acceptance_email_send'
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    public function pharmacist() {
        return $this->hasOne('App\Model\Pharmacist', 'user_id', 'id')->withDefault();
    }

    public function pharmacistSkill() {
        return $this->hasMany('App\Model\PharmacistSkill', 'user_id', 'id');
    }

    public function pharmacistRegion() {
        return $this->hasMany('App\Model\PharmacistRegion', 'user_id', 'id');
    }

    public function pharmacy() {
        return $this->hasOne('App\Model\Pharmacy', 'id', 'pharmacy_id')->withDefault();
    }

    public function pharmacyLocation() {
        return $this->hasMany('App\Model\Pharmacy', 'user_id', 'id');
    }

    public function pharmacyByUserId() {
        return $this->hasMany('App\Model\Pharmacy', 'user_id', 'id');
    }
}
