@extends('admin.layouts.app')

@section('title', $title)

@section('head')
<!-- third party css -->
<link href="{{ asset('admin/plugins/datatables-bs4/css/dataTables.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
<link href="{{ asset('admin/plugins/datatables-responsive/css/responsive.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
<link href="{{ asset('admin/plugins/datatables-buttons/css/buttons.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
<!-- third party css end -->
@endsection

@section('content')
    <section class="content-header">
      <div class="container-fluid">
        <div class="row mb-2">
          <div class="col-sm-6">
            <h1>{{$title}}</h1>
          </div>
          <div class="col-sm-6">
            <ol class="breadcrumb float-sm-right">
              <li class="breadcrumb-item"><a href="{{route('admin.dashboard')}}">Home</a></li>
              <li class="breadcrumb-item active">{{$title}}</li>
            </ol>
          </div>
        </div>
      </div>
    </section>
    <!-- Main content -->
    <section class="content">

      <!-- Default box -->
      <div class="card">
        <div class="card-header">
          <h3 class="card-title">{{$title}}</h3>

          <div class="card-tools">
            <button type="button" class="btn btn-tool" data-card-widget="collapse" title="Collapse">
              <i class="fas fa-minus"></i>
            </button>
          </div>
        </div>
        <div class="card-body">
            <table id="dataTable" class="table table-bordered table-hover">
                <thead>
                    <tr>
                        <th>Id</th>
                        <th>Name</th>
                        <th width="250px">Date</th>
                        <th>Created By</th>
                        <th>Status</th>
                        <th>Notes</th>
                        <th>Action</th>
                    </tr>
                </thead>
                <tbody>
                    @foreach ($dataArr as $booking)
                        <tr>
                            <td>{{$booking->id}}</td>
                            <td>{{$booking->user->name ?? $booking->user->firstname.' '.$booking->user->lastname }}</td>
                            @php
                              $dates = [];
                              foreach($booking->date as $k => $v) {
                                $dates[$k] = date("d-m-Y", strtotime($v));
                              }
                            @endphp
                            <td>{{implode(", ", $dates)}}</td>
                            <td>{{$booking->createdBy->name ?? $booking->createdBy->firstname.' '.$booking->createdBy->lastname }}</td>
                            <td>
                                @if ($booking->status == 0)
                                    Requested
                                @elseif ($booking->status == 1)
                                    Accepted
                                @else
                                    Declined
                                @endif
                            </td>
                            <td>{{$booking->notes}}</td>
                            <td>
                                <a href="{{route('admin.booking.invoice-list', $booking->id)}}">Invoice List</a>
                            </td>
                        </tr>
                    @endforeach
                </tbody>
            </table>
        </div>
      </div>
    </section>
@endsection

@section('script')
<!-- third party js -->
<script src="{{ asset('admin/plugins/datatables/jquery.dataTables.min.js') }}"></script>
<script src="{{ asset('admin/plugins/datatables-bs4/js/dataTables.bootstrap4.min.js') }}"></script>
<script src="{{ asset('admin/plugins/datatables-responsive/js/dataTables.responsive.min.js') }}"></script>
<script src="{{ asset('admin/plugins/datatables-responsive/js/responsive.bootstrap4.min.js') }}"></script>
<script src="{{ asset('admin/plugins/bootstrap-switch/js/bootstrap-switch.min.js') }}"></script>

<!-- third party js ends -->
<script>
jQuery(document).ready(function($) {
    $("#dataTable").DataTable({
        "order": [[ 0, "desc" ]],
    });
});

</script>
@endsection