@extends('admin.layouts.app')

@section('title') Dashboard @endsection

@section('head')
<!-- third party css -->
<link href="{{ asset('admin/plugins/datatables-bs4/css/dataTables.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
<link href="{{ asset('admin/plugins/datatables-responsive/css/responsive.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
<link href="{{ asset('admin/plugins/datatables-buttons/css/buttons.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
<!-- third party css end -->
@endsection

@section('content')
    <!-- Content Header (Page header) -->
    <section class="content-header">
      <div class="container-fluid">
        <div class="row mb-2">
          <div class="col-sm-6">
            <h1>Dashboard</h1>
          </div>
          <div class="col-sm-6">
            <ol class="breadcrumb float-sm-right">
              <li class="breadcrumb-item"><a href="{{route('admin.dashboard')}}">Home</a></li>
            </ol>
          </div>
        </div>
      </div><!-- /.container-fluid -->
    </section>

    <!-- Main content -->
    <section class="content">

      <!-- Default box -->
      <div class="card">
        <div class="card-header">
          <h3 class="card-title">Recent Pharmacist / Technician</h3>

          <div class="card-tools">
            <button type="button" class="btn btn-tool" data-card-widget="collapse" title="Collapse">
              <i class="fas fa-minus"></i>
            </button>
          </div>
        </div>
        <div class="card-body">
            <table id="dataTable" class="table table-bordered table-hover">
                <thead>
                    <tr>
                        <th>Id</th>
                        <th>Username</th>
                        <th>Type</th>
                        <th>First Name</th>
                        <th>Last name</th>
                        <th>Preferred Name</th>
                        <th>Location</th>
                        <th>Email</th>
                        <th data-orderable="false">Action</th>
                    </tr>
                </thead>
                <tbody>
                    @foreach ($pharmacies as $data)
                        <tr>
                            <td><a href="javascript:;" onclick="showPharmaciesDetails({{$data->id}})">{{$data->id}}</a></td>
                            <td>{{$data->username}}</td>
                            <td>{{$data->pharmacist->is_pharmacist ? ($data->pharmacist->is_pharmacist == 2 ? 'Technician' : 'Pharmacist') : ''}}</td>
                            <td>{{$data->firstname}}</td>
                            <td>{{$data->lastname}}</td>
                            <td>{{$data->pharmacist->known_as}}</td>
                            <td>{{$data->pharmacist->location}}</td>
                            <td>{{$data->email}}</td>
                            <td>
                                <input type="checkbox" name="my-checkbox" {{!$data->status ? "checked" : ''}} data-pharmacies data-id="{{$data->id}}" class="js-pharmacies-small-{{$data->id}}">
                            </td>
                        </tr>
                    @endforeach
                </tbody>
            </table>
        </div>
        <!-- /.card-body -->
        <div class="card-footer">
          Footer
        </div>
        <!-- /.card-footer-->
      </div>
      <!-- /.card -->
      <div class="card">
        <div class="card-header">
          <h3 class="card-title">Recent Pharmacy</h3>

          <div class="card-tools">
            <button type="button" class="btn btn-tool" data-card-widget="collapse" title="Collapse">
              <i class="fas fa-minus"></i>
            </button>
          </div>
        </div>
        <div class="card-body">
          <table id="dataTable" class="table table-bordered table-hover">
                <thead>
                    <tr>
                        <th>Id</th>
                        <th>Username</th>
                        <th>Name</th>
                        <th>Email</th>
                        <th data-orderable="false">Action</th>
                    </tr>
                </thead>
                <tbody>
                    @foreach ($pharmacys as $data)
                        <tr>
                            <td><a href="javascript:;" onclick="showDetails({{$data->id}})">{{$data->id}}</a></td>
                            <td>{{$data->username}}</td>
                            <td>{{$data->name}}</td>
                            <td>{{$data->email}}</td>
                            <td>
                                <input type="checkbox" name="my-checkbox" {{!$data->status ? "checked" : ''}} data-bootstrap-switch data-id="{{$data->id}}" class="js-switch-small-{{$data->id}}">
                            </td>
                        </tr>
                    @endforeach
                </tbody>
            </table>
        </div>
        <!-- /.card-body -->
        <div class="card-footer">
          Footer
        </div>
        <!-- /.card-footer-->
      </div>
      <!-- /.card -->
    </section>
    <div id="show_details" class="modal fade" role="dialog">
          <div class="modal-dialog modal-lg">

            <!-- Modal content-->
            <div class="modal-content">
              <div class="modal-header">
                <h4 class="modal-title">Detail</h4>
                <button type="button" class="close" data-dismiss="modal">&times;</button>
              </div>
              <div class="modal-body" id="show_details_body">
              </div>
              <div class="modal-footer">
                <button type="button" class="btn btn-default" data-dismiss="modal">Ok</button>
              </div>
            </div>

          </div>
    </div>
@endsection
@section('script')
<!-- third party js -->
<script src="{{ asset('admin/plugins/datatables/jquery.dataTables.min.js') }}"></script>
<script src="{{ asset('admin/plugins/datatables-bs4/js/dataTables.bootstrap4.min.js') }}"></script>
<script src="{{ asset('admin/plugins/datatables-responsive/js/dataTables.responsive.min.js') }}"></script>
<script src="{{ asset('admin/plugins/datatables-responsive/js/responsive.bootstrap4.min.js') }}"></script>
<script src="{{ asset('admin/plugins/bootstrap-switch/js/bootstrap-switch.min.js') }}"></script>

<!-- third party js ends -->
<script>
jQuery(document).ready(function($) {
    $("#dataTable").DataTable({
        "order": [[ 0, "desc" ]],
    });
});

$("input[data-pharmacies]").each(function(){
  $(this).bootstrapSwitch({
        onText : 'OFF',
        onColor : 'danger',
        offText : 'ON',
        offColor : 'success',
        onSwitchChange: function (event, state) {
            id = $(event.currentTarget).data("id");
            if (confirm("are you sure want to change status?")) {
                var url = "{{ route('admin.pharmacist.changeStatus') }}?id="+id;
                showLoader();
                $.ajaxSetup({
                    headers: {
                        'X-CSRF-TOKEN': '{{csrf_token()}}'
                    }
                });
                $.ajax({
                    type: "POST",
                    url: url,
                    data : {
                        status : $(".js-pharmacies-small-"+id).prop("checked") ? 0 : 1
                    },
                    success: function( res ) {
                        if (res.code == 200 || res.code == 0) {
                            msg = res.msg;
                            showToaster("success", msg);
                            window.location.reload();
                        } else {
                            showToaster("error", res.msg);
                        }
                        hideLoader();
                    }
                });
                return true;
            } else {
                return false;
            }
        }
    });
});

function showPharmaciesDetails(id) {
    var url = "{{ route('admin.pharmacist.show', ':ids')}}"
    url = url.replace(':ids', id);
    showLoader();
    $.ajaxSetup({
        headers: {
            'X-CSRF-TOKEN': '{{csrf_token()}}'
        }
    });
    $.ajax({
        url: url,
        success: function( res ) {
            $("#show_details_body").html(res);
            $("#show_details").modal('show');
            hideLoader();
        }
    });
}

$("input[data-bootstrap-switch]").each(function(){
  $(this).bootstrapSwitch({
        onText : 'OFF',
        onColor : 'danger',
        offText : 'ON',
        offColor : 'success',
        onSwitchChange: function (event, state) {
            id = $(event.currentTarget).data("id");
            if (confirm("are you sure want to change status?")) {
                var url = "{{ route('admin.pharmacy.changeStatus') }}?id="+id;
                showLoader();
                $.ajaxSetup({
                    headers: {
                        'X-CSRF-TOKEN': '{{csrf_token()}}'
                    }
                });
                $.ajax({
                    type: "POST",
                    url: url,
                    data : {
                        status : $(".js-switch-small-"+id).prop("checked") ? 0 : 1
                    },
                    success: function( res ) {
                        if (res.code == 200 || res.code == 0) {
                            msg = res.msg;
                            showToaster("success", msg);
                            window.location.reload();
                        } else {
                            showToaster("error", res.msg);
                        }
                        hideLoader();
                    }
                });
                return true;
            } else {
                return false;
            }
        }
    });
});
function showDetails(id) {
    var url = "{{ route('admin.pharmacy.show', ':ids')}}"
    url = url.replace(':ids', id);
    showLoader();
    $.ajaxSetup({
        headers: {
            'X-CSRF-TOKEN': '{{csrf_token()}}'
        }
    });
    $.ajax({
        url: url,
        success: function( res ) {
            $("#show_details_body").html(res);
            $("#show_details").modal('show');
            hideLoader();
        }
    });
}
</script>
@endsection
