@extends('admin.layouts.app')

@section('title', $title)

@section('content')
    <section class="content-header">
      <div class="container-fluid">
        <div class="row mb-2">
          <div class="col-sm-6">
            <h1>{{$title}}</h1>
          </div>
          <div class="col-sm-6">
            <ol class="breadcrumb float-sm-right">
              <li class="breadcrumb-item"><a href="{{route('admin.dashboard')}}">Home</a></li>
              <li class="breadcrumb-item active">{{$title}}</li>
            </ol>
          </div>
        </div>
      </div>
    </section>
    <!-- Main content -->
    <section class="content">

      <!-- Default box -->
      <div class="card">
        <div class="card-header">
          <h3 class="card-title">{{$title}}</h3>

          <div class="card-tools">
            <button type="button" class="btn btn-tool" data-card-widget="collapse" title="Collapse">
              <i class="fas fa-minus"></i>
            </button>
          </div>
        </div>
        <div class="card-body">
            <form id="quickForm" method="post">
                @csrf
                <input type="hidden" name="action" value="update">
                <input type="hidden" name="id" value="{{$user->id}}">
                <div class="form-group">
                     <label for="name">Pharmacy Name</label>
                    <input type="text"  class="form-control" required placeholder="Pharmacy Name" name="pharmacy_name" value="{{$user->pharmacy->pharmacy_name}}">
                </div>
                <div class="form-group">
                    <label for="address">Address</label>
                  <input type="text" class="form-control" required placeholder="Address" name="address" value="{{$user->pharmacy->address}}">
                </div>
                <div class="form-group">
                    <label for="region_id">Select Areas for work</label>
                    <select class="form-control"  name="region_id">
                       <option value=""> Select Areas for work</option>
                       @foreach($region as $value)
                        <option value="{{$value->id}}" {{$value->id == $user->pharmacy->region_id ? 'selected' : ''}}>{{$value->name}}</option>
                       @endforeach
                    </select>
                </div>
                <div class="form-group">
                     <label for="owner_name">Owner's Name</label>
                  <input type="text" class="form-control" required placeholder="Owner's Name" name="owner_name" value="{{$user->pharmacy->owner_name}}">
                </div>
                <div class="form-group">
                    <label for="contact_phone">Contact Phone</label>
                  <input type="text" class="form-control" required placeholder="Contact Phone" name="contact_phone" value="{{$user->pharmacy->contact_phone}}">
                </div>
                <div class="form-group">
                    <label for="email">Contact Email</label>
                  <input type="text" class="form-control" required placeholder="Contact Email" name="email" value="{{$user->pharmacy->email}}">
                </div>
                <div class="form-group">
                    <h3>Uploads</h3>
                    <label class="upload-file" style="padding-top: 0px;">License</label>
                    <input class="form-control" type="file" name="uploads_license">
                    @if (!empty($user->pharmacy->uploads_license))
                        <br>
                        {!! fileShow('/uploads/pharmacy/uploads_license/', $user->pharmacy->uploads_license, '30%') !!}
                    @endif
                </div>
            <div class="card-footer">
              <button type="submit" class="btn btn-primary">Submit</button>
              <a href="{{route('admin.pharmacy.index')}}" class="btn btn-info">Cancel</a>
            </div>
          </form>
        </div>
      </div>
    </section>
@endsection

@section('script')
<script src="{{ asset('admin/plugins/jquery-validation/jquery.validate.min.js') }}"></script>
<script type="text/javascript">

  $('#quickForm').submit(function(e) {
    e.preventDefault();
    showLoader();
    var formData = new FormData($("#quickForm")[0]);
    $.ajax({
        type: "POST",
        url: "{{ route('admin.pharmacy.store') }}",
        data: formData,
        processData: false,
        contentType: false,
        success: function( res ) {
            if (res.code == 200 || res.code == 0) {
                msg = res.msg;
                showToaster("success", msg);
                setTimeout( function(){
                    redirectUrl = "{{ route('admin.pharmacy.index') }}";
                    window.location.href = redirectUrl;
                }  , 1000 );

            } else {
                showToaster("error", res.msg);
            }
            hideLoader();
        }
    });
  });

</script>
@endsection
