@extends('admin.layouts.app')

@section('title', $title)

@section('head')
<!-- third party css -->
<link href="{{ asset('admin/plugins/datatables-bs4/css/dataTables.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
<link href="{{ asset('admin/plugins/datatables-responsive/css/responsive.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
<link href="{{ asset('admin/plugins/datatables-buttons/css/buttons.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
<!-- third party css end -->
@endsection

@section('content')
    <section class="content-header">
      <div class="container-fluid">
        <div class="row mb-2">
          <div class="col-sm-6">
            <h1>{{$title}}</h1>
          </div>
          <div class="col-sm-6">
            <ol class="breadcrumb float-sm-right">
              <li class="breadcrumb-item"><a href="{{route('admin.dashboard')}}">Home</a></li>
              <li class="breadcrumb-item active">{{$title}}</li>
            </ol>
          </div>
        </div>
      </div>
    </section>
    <!-- Main content -->
    <section class="content">

      <!-- Default box -->
      <div class="card">
        <div class="card-header">
          <h3 class="card-title">{{$title}}</h3>

          <div class="card-tools">
            <a href="{{route('admin.region.create')}}" class="btn btn-tool text-primary">
              <i class="fas fa-plus"></i> Create
            </a>
            <button type="button" class="btn btn-tool" data-card-widget="collapse" title="Collapse">
              <i class="fas fa-minus"></i>
            </button>
          </div>
        </div>
        <div class="card-body">
            <table id="dataTable" class="table table-bordered table-hover">
                <thead>
                    <tr>
                        <th>Id</th>
                        <th>Name</th>
                        <th data-orderable="false">Action</th>
                    </tr>
                </thead>
                <tbody>
                    @foreach ($dataArr as $data)
                        <tr>
                            <td>{{$data->id}}</td>
                            <td>{{$data->name}}</td>
                            <td>
                                <input type="checkbox" name="my-checkbox" {{$data->status ? "checked" : ''}} data-bootstrap-switch data-id="{{$data->id}}" class="js-switch-small-{{$data->id}}">
                                <a href="{{route('admin.region.edit', $data->id)}}"><i class="fas fa-edit"></i></a>
                                <a href="javascript:;" onclick="deleteData({{$data->id}})"><i class="fas fa-trash"></i></a>
                            </td>
                        </tr>
                    @endforeach
                </tbody>
            </table>
        </div>
      </div>
    </section>
@endsection

@section('script')
<!-- third party js -->
<script src="{{ asset('admin/plugins/datatables/jquery.dataTables.min.js') }}"></script>
<script src="{{ asset('admin/plugins/datatables-bs4/js/dataTables.bootstrap4.min.js') }}"></script>
<script src="{{ asset('admin/plugins/datatables-responsive/js/dataTables.responsive.min.js') }}"></script>
<script src="{{ asset('admin/plugins/datatables-responsive/js/responsive.bootstrap4.min.js') }}"></script>
<script src="{{ asset('admin/plugins/bootstrap-switch/js/bootstrap-switch.min.js') }}"></script>

<!-- third party js ends -->
<script>
jQuery(document).ready(function($) {
    $("#dataTable").DataTable({
        "order": [[ 0, "desc" ]],
    });
});

function deleteData(id) {
    if (confirm("are you sure want to delete?")) {
        var url = "{{ route('admin.region.destroy', ':ids')}}"
        url = url.replace(':ids', id);
        showLoader();
        $.ajaxSetup({
            headers: {
                'X-CSRF-TOKEN': '{{csrf_token()}}'
            }
        });
        $.ajax({
            type: "delete",
            url: url,
            success: function( res ) {
                if (res.code == 200 || res.code == 0) {
                    msg = res.msg;
                    showToaster("success", msg);
                    window.location.reload();
                } else {
                    showToaster("error", res.msg);
                }
                hideLoader();
            }
        });
    }
}

$("input[data-bootstrap-switch]").each(function(){
  $(this).bootstrapSwitch({
        onText : 'OFF',
        onColor : 'danger',
        offText : 'ON',
        offColor : 'success',
        onSwitchChange: function (event, state) {
            id = $(event.currentTarget).data("id");
            if (confirm("are you sure want to change status?")) {
                var url = "{{ route('admin.region.changeStatus') }}?id="+id;
                showLoader();
                $.ajaxSetup({
                    headers: {
                        'X-CSRF-TOKEN': '{{csrf_token()}}'
                    }
                });
                $.ajax({
                    type: "POST",
                    url: url,
                    data : {
                        status : $(".js-switch-small-"+id).prop("checked") ?  1 : 0
                    },
                    success: function( res ) {
                        if (res.code == 200 || res.code == 0) {
                            msg = res.msg;
                            showToaster("success", msg);
                            //window.location.reload();
                        } else {
                            showToaster("error", res.msg);
                        }
                        hideLoader();
                    }
                });
                return true;
            } else {
                return false;
            }
        }
    });
});
</script>
@endsection