@extends('admin.layouts.app')

@section('title', $title)

@section('head')
<!-- third party css -->
<link href="{{ asset('admin/plugins/datatables-bs4/css/dataTables.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
<link href="{{ asset('admin/plugins/datatables-responsive/css/responsive.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
<link href="{{ asset('admin/plugins/datatables-buttons/css/buttons.bootstrap4.min.css') }}" rel="stylesheet" type="text/css" />
<!-- third party css end -->
@endsection

@section('content')
    <section class="content-header">
      <div class="container-fluid">
        <div class="row mb-2">
          <div class="col-sm-6">
            <h1>{{$title}}</h1>
          </div>
          <div class="col-sm-6">
            <ol class="breadcrumb float-sm-right">
              <li class="breadcrumb-item"><a href="{{route('admin.dashboard')}}">Home</a></li>
              <li class="breadcrumb-item active">{{$title}}</li>
            </ol>
          </div>
        </div>
      </div>
    </section>
    <!-- Main content -->
    <section class="content">

      <!-- Default box -->
      <form id="quickForm">
            @csrf
              <div class="card">
                <div class="card-header">
                  <h3 class="card-title">{{$title}}</h3>
        
                  <div class="card-tools">
                    <button type="button" class="btn btn-tool" data-card-widget="collapse" title="Collapse">
                      <i class="fas fa-minus"></i>
                    </button>
                  </div>
                </div>
                <div class="card-body">
                    <table id="dataTable" class="table table-bordered table-hover">
                        <thead>
                            <tr>
                                <th>Name</th>
                                <th>Value</th>
                            </tr>
                        </thead>
                        <tbody>
                            @foreach ($dataArr as $data)
                                <tr>
                                    <td> <label for="setting{{$data->id}}">{{$data->name}}</label></td>
                                    <td><textarea id="setting{{$data->id}}" name="setting[{{$data->id}}]" class="form-control" >{!! $data->value !!}</textarea></td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
                <div class="card-footer">
                    <button type="submit" class="btn btn-primary">Submit</button>
                </div>
              </div>
        </form>
    </section>
@endsection

@section('script')
<script>
    $('#quickForm').submit(function(e) {
        e.preventDefault();
        showLoader();
        var formData = new FormData($("#quickForm")[0]);
        $.ajax({
            type: "POST",
            url: "{{ route('admin.setting.store')}}",
            data: formData,
            processData: false,
            contentType: false,
            success: function( res ) {
                if (res.code == 200 || res.code == 0) {
                    msg = res.msg;
                    showToaster("success", msg);
                    setTimeout( function(){ 
                        redirectUrl = "{{ route('admin.setting.index') }}";
                        window.location.href = redirectUrl;
                    }  , 1000 );
                    
                } else {
                    showToaster("error", res.msg);
                }
                hideLoader();
            }
        });
    });
</script>
@endsection