@extends('admin.layouts.app')

@section('title', $title)

@section('content')
    <section class="content-header">
      <div class="container-fluid">
        <div class="row mb-2">
          <div class="col-sm-6">
            <h1>{{$title}}</h1>
          </div>
          <div class="col-sm-6">
            <ol class="breadcrumb float-sm-right">
              <li class="breadcrumb-item"><a href="{{route('admin.dashboard')}}">Home</a></li>
              <li class="breadcrumb-item active">{{$title}}</li>
            </ol>
          </div>
        </div>
      </div>
    </section>
    <!-- Main content -->
    <section class="content">

      <!-- Default box -->
      <div class="card">
        <div class="card-header">
          <h3 class="card-title">{{$title}}</h3>

          <div class="card-tools">
            <button type="button" class="btn btn-tool" data-card-widget="collapse" title="Collapse">
              <i class="fas fa-minus"></i>
            </button>
          </div>
        </div>
        <div class="card-body">
            <form id="quickForm">
                @csrf
                <input type="hidden" name="action" value="{{$action}}">
                <input type="hidden" name="id" value="{{$model->id}}">
                @if ($action == 'add') 
                    <input type="hidden" name="status" value="1">
                @endif
                <div class="card-body">
                  <div class="form-group">
                    <label for="name">Name</label>
                    <input type="text" name="name" class="form-control" id="name" placeholder="Enter name" value="{{$model->name}}">
                  </div>
                </div>
                <!-- /.card-body -->
                <div class="card-footer">
                  <button type="submit" class="btn btn-primary">Submit</button>
                  <a href="{{route('admin.skill.index')}}" class="btn btn-info">Cancel</a>
                </div>
              </form>
        </div>
      </div>
    </section>
@endsection

@section('script')
<script src="{{ asset('admin/plugins/jquery-validation/jquery.validate.min.js') }}"></script>
<script type="text/javascript">
    $.validator.setDefaults({
    submitHandler: function () {
        showLoader();
        var formData = new FormData($("#quickForm")[0]);
        $.ajax({
            type: "POST",
            url: "{{ route('admin.skill.store')}}",
            data: formData,
            processData: false,
            contentType: false,
            success: function( res ) {
                if (res.code == 200 || res.code == 0) {
                    msg = res.msg;
                    showToaster("success", msg);
                    setTimeout( function(){ 
                        redirectUrl = "{{ route('admin.skill.index') }}";
                        window.location.href = redirectUrl;
                    }  , 1000 );
                    
                } else {
                    showToaster("error", res.msg);
                }
                hideLoader();
            }
        });
    }
  });
  $('#quickForm').validate({
    rules: {
      name: {
        required: true
      },
    },
    messages: {
      name: {
        required: "Please enter a skill name"
      }
    },
    errorElement: 'span',
    errorPlacement: function (error, element) {
      error.addClass('invalid-feedback');
      element.closest('.form-group').append(error);
    },
    highlight: function (element, errorClass, validClass) {
      $(element).addClass('is-invalid');
    },
    unhighlight: function (element, errorClass, validClass) {
      $(element).removeClass('is-invalid');
    }
  });
</script>
@endsection
