<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Auth::routes();
Route::get('/logout', 'Auth\LoginController@logout')->name('logout');
Route::get('/sendmail', function() {
	$user = \App\User::find(1);
	\Mail::send('mail.user-ragister', ['name' => $user->username], function($message) use($user){
		$message->to('chintansanghani25@gmail.com');
		$message->subject('Thank you for registering on Pharmacy Recruit');
	});
	echo 'done';
})->name('sendmail');

$adminDomain = config('app.app_admin_domain');
Route::group(['domain' => $adminDomain, 'as' => 'admin.'], function () {
    Route::group([ 'namespace' => 'Admin', 'middleware'=> ['auth']], function() {
    	Route::get('/', 'HomeController@index')->name('dashboard');

    	Route::post('skill/changeStatus', 'SkillController@changeStatus')->name("skill.changeStatus");
    	Route::resource('skill', 'SkillController');
        
        Route::post('level/changeStatus', 'LevelController@changeStatus')->name("level.changeStatus");
    	Route::resource('level', 'LevelController');
    	
    	Route::post('pharmacist/changeStatus', 'PharmacistController@changeStatus')->name("pharmacist.changeStatus");
    	Route::resource('pharmacist', 'PharmacistController');

    	Route::post('pharmacy/changeStatus', 'PharmacyController@changeStatus')->name("pharmacy.changeStatus");
    	Route::resource('pharmacy', 'PharmacyController');

    	Route::post('region/changeStatus', 'RegionController@changeStatus')->name("region.changeStatus");
    	Route::resource('region', 'RegionController');
        
        Route::get('booking/{id}/invoice-list', 'BookingController@invoiceList')->name('booking.invoice-list');
        Route::get('booking/{id}/invoice/create', 'BookingController@invoiceCreate')->name('booking.invoice-create');
        Route::get('booking/{id}/invoice/{invoice_id}', 'BookingController@invoice')->name('booking.invoice');
        Route::post('booking/saveInvoice', 'BookingController@saveInvoice')->name('booking.saveInvoice');
        
    	Route::resource('booking', 'BookingController');
    	
    	Route::resource('cms', 'CmsController');
    	
    	Route::resource('faq', 'FaqController');
    	
    	Route::resource('setting', 'SettingController');
    });
});
$domain = config('app.app_domain');

Route::group(['domain' => $domain, 'namespace' => 'Front', 'middleware' => 'auth'], function () {
	Route::get('/', function() {
		if (auth()->user()->roles->first()->id == '2') {
			return redirect()->route('pharmacist.dashboard');
		}

		if (auth()->user()->roles->first()->id == '3') {
			return redirect()->route('pharmacy.dashboard');
		}
	})->name('home')->middleware('show_registration');

	Route::get('/thanks-for-registering', function(){
	    if (auth()->user()->is_acceptance_email_send == '1') {
			return redirect()->route('profile.dashboard');
		}
	    \Auth::logout();
		return view('front.thanks-for-registering');
	})->name('thanks-for-registering');
    
    Route::get('/invoice', 'HomeController@invoice');
    
	Route::group([ 'prefix' => 'pharmacist', 'as' => 'pharmacist.'], function() {
    	Route::get('registration', 'PharmacistController@registration')->name('registration');
    	Route::post('registration-save', 'PharmacistController@store')->name('registration.store');
    	Route::group(['middleware' => 'show_registration'], function() {
	    	Route::get('/', 'PharmacistController@dashboard')->name('dashboard');
	    	Route::get('edit', 'PharmacistController@edit')->name('edit');
	    	Route::get('add-availability', 'AvailabilityOrVacancyController@create')->name('add-availability');
	    	Route::get('edit-availability/{id}', 'AvailabilityOrVacancyController@create')->name('edit-availability');

	    	Route::get('job/{sorted?}', 'PharmacistController@job')->name('job');
	    	Route::get('request-a-pharmacy/{id}', 'PharmacistController@pharmacy')->name('pharmacy');
	    	
	    	Route::get('/request-sent', function(){
	    		return view('front.pharmacist.request-sent');
	    	})->name('request-sent');
	    	
    	});
	});

	Route::group([ 'prefix' => 'pharmacy', 'as' => 'pharmacy.'], function() {
    	Route::get('registration', 'PharmacyController@registration')->name('registration');
    	Route::post('registration-save', 'PharmacyController@store')->name('registration.store');
    	Route::group(['middleware' => 'show_registration'],function() {
	    	Route::get('/', 'PharmacyController@dashboard')->name('dashboard');
	    	Route::get('edit', 'PharmacyController@edit')->name('edit');
	    	Route::get('add-vacancy', 'AvailabilityOrVacancyController@create')->name('add-vacancy');
	    	Route::get('edit-availability/{id}', 'AvailabilityOrVacancyController@create')->name('edit-vacancy');
	    	Route::get('search/{sorted?}', 'PharmacyController@search')->name('search');
	    	Route::get('request-a-pharmacist/{id}', 'PharmacyController@pharmacist')->name('pharmacist');

	    	Route::get('switchbaord', 'PharmacyLocationController@switchbaord')->name('switchbaord');
	    	Route::get('add-location', 'PharmacyLocationController@addLocation')->name('add-location');
	    	Route::post('add-location', 'PharmacyLocationController@storeLocation')->name('add-location.save');
	    	Route::post('change-location', 'PharmacyLocationController@changeLocation')->name('change-location');
	    	Route::post('destroy', 'PharmacyController@destroy')->name('destroy');

	    	Route::get('/offer-sent', function(){
	    		return view('front.pharmacy.offer-sent');
	    	})->name('offer-sent');

	    });
	});

	Route::group(['middleware' => 'show_registration'],function() {
    	Route::post('availability-or-vacancy-save', 'AvailabilityOrVacancyController@store')->name('availability-or-vacancy.store');
    	Route::post('booking-save', 'BookingsController@store')->name('booking.save');

    	Route::get('my-booking', 'BookingsController@index')->name('booking.index');

    	Route::get('booking/{id}', 'BookingsController@show')->name('booking.show');
    	Route::get('booking/{id}/change-status/{status}', 'BookingsController@changeStatus')->name('booking.change-status');
    	Route::get('booking/{id}/pay', 'BookingsController@payment')->name('booking.pay');
    	Route::get('booking/{id}/invoice', 'BookingsController@invoice')->name('booking.invoice');
    	Route::post('booking/payment-succeeded', 'BookingsController@paymentSucceeded')->name('payment-succeeded');
    	Route::get('request-from-pharmacist/{id}', 'BookingsController@requestFromPharmacist')->name('request-from-pharmacist');
    	Route::get('request-from-pharmacy/{id}', 'BookingsController@requestFromPharmacy')->name('request-from-pharmacy');


    	Route::get('/notification', function() {

    		if (auth()->user()->roles->first()->id == '2') {
    			$notification = \App\Model\Notification::where('user_id', auth()->user()->id)->latest()->paginate(5);
				\App\Model\Notification::where('user_id', auth()->user()->id)->update(['is_new' => '0']);
    		}

    		if (auth()->user()->roles->first()->id == '3') {
    			$notification = \App\Model\Notification::where('pharmacy_id', auth()->user()->pharmacy_id)
											->where('user_id', auth()->user()->id)->latest()->paginate(5);

				\App\Model\Notification::where('pharmacy_id', auth()->user()->pharmacy_id)
										->where('user_id', auth()->user()->id)->update(['is_new' => '0']);
    		}

    		return view('front.notification', compact('notification'));
    	})->name('notification');

    });
    Route::get('/privacy-policy', function() {
		return view('front.privacy-policy');
	})->name('privacy-policy');
	
	Route::get('/terms-and-conditions', function() {
		return view('front.terms-and-conditions');
	})->name('terms-and-conditions');
    
    Route::get('/cancellation-policy', function() {
		return view('front.cancellation-policy');
	})->name('cancellation-policy');
	
    Route::get('/profile-dashboard', function() {
		if (auth()->user()->roles->first()->id == '2') {
			return redirect()->route('pharmacist.dashboard');
		}

		if (auth()->user()->roles->first()->id == '3') {
			return redirect()->route('pharmacy.dashboard');
		}
	})->name('profile.dashboard')->middleware('show_registration');
	
	Route::get('/faqs', function() {
		return view('front.faqs');
	})->name('faqs');
    
});

